DataSet
*******

DataSet
=======
.. autoclass:: ai4water.preprocessing.DataSet
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

DataSetUnion
============
.. autoclass:: ai4water.preprocessing.DataSetUnion
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

DataSetPipeline
================
.. autoclass:: ai4water.preprocessing.DataSetPipeline
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__
